==> commons-math_2.0.orig.tar.gz: commons-math-2.0-src/src/main/java/org/apache/commons/math/geometry/CardanEulerSingularityException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.math.geometry;

import org.apache.commons.math.MathException;

/** This class represents exceptions thrown while extractiong Cardan
 * or Euler angles from a rotation.

 * @version $Revision: 746578 $ $Date: 2009-02-21 15:01:14 -0500 (Sat, 21 Feb 2009) $
 * @since 1.2
 */
public class CardanEulerSingularityException
  extends MathException {

  /** 
   * Simple constructor.
   * build an exception with a default message.
   * @param isCardan if true, the rotation is related to Cardan angles,
   * if false it is related to EulerAngles
   */
  public CardanEulerSingularityException(boolean isCardan) {
    super(isCardan ? "Cardan angles singularity" : "Euler angles singularity");
  }

  /** Serializable version identifier */
  private static final long serialVersionUID = -1360952845582206770L;

}

==> commons-math_2.2.orig.tar.gz: commons-math-2.2-src/src/main/java/org/apache/commons/math/geometry/CardanEulerSingularityException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.math.geometry;

import org.apache.commons.math.MathException;
import org.apache.commons.math.exception.util.LocalizedFormats;

/** This class represents exceptions thrown while extractiong Cardan
 * or Euler angles from a rotation.

 * @version $Revision: 983921 $ $Date: 2010-08-10 12:46:06 +0200 (mar. 10 août 2010) $
 * @since 1.2
 */
public class CardanEulerSingularityException
  extends MathException {

    /** Serializable version identifier */
    private static final long serialVersionUID = -1360952845582206770L;

    /**
     * Simple constructor.
     * build an exception with a default message.
     * @param isCardan if true, the rotation is related to Cardan angles,
     * if false it is related to EulerAngles
     */
    public CardanEulerSingularityException(boolean isCardan) {
        super(isCardan ? LocalizedFormats.CARDAN_ANGLES_SINGULARITY : LocalizedFormats.EULER_ANGLES_SINGULARITY);
    }

}
